using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using PdfSharp;
using MigraDoc;

namespace MigraDocBulletsExample
{
    class Program
    {

        static void RenderBullets(
            string[] p_List,
            PdfSharp.Drawing.XGraphics p_Graphics,
            MigraDoc.DocumentObjectModel.ListType p_BulletType,
            Double p_BulletWidth,
            Double p_X,
            Double p_Y,
            Double p_Width
        )
        {

            PdfSharp.Drawing.XUnit X = PdfSharp.Drawing.XUnit.FromInch(p_X);
            PdfSharp.Drawing.XUnit Y = PdfSharp.Drawing.XUnit.FromInch(p_Y);
            PdfSharp.Drawing.XUnit Width = PdfSharp.Drawing.XUnit.FromInch(p_Width);
            MigraDoc.DocumentObjectModel.Document TheDocument;
            MigraDoc.DocumentObjectModel.Section TheSection;
            MigraDoc.DocumentObjectModel.Shapes.TextFrame TheTextFrame;
            MigraDoc.DocumentObjectModel.Paragraph TheParagraph;
            MigraDoc.DocumentObjectModel.Style TheStyle;
            MigraDoc.DocumentObjectModel.ListInfo TheListInfo;
            Int32 NumberOfItems;
            Int32 ItemIndex;
            string TheItem;
            string StyleName;
            MigraDoc.Rendering.DocumentRenderer TheDocumentRenderer;

            TheDocument = new MigraDoc.DocumentObjectModel.Document();

            TheSection = TheDocument.AddSection();

            TheTextFrame = TheSection.AddTextFrame();

            StyleName = "List-" + p_BulletType.ToString();

            TheStyle = TheDocument.AddStyle(StyleName, "Normal");

            TheStyle.ParagraphFormat.LeftIndent = MigraDoc.DocumentObjectModel.Unit.FromInch(p_BulletWidth);

            for (ItemIndex = 0, NumberOfItems = p_List.Length; ItemIndex < NumberOfItems; ItemIndex++)
            {

                TheItem = p_List[ItemIndex];

                TheListInfo = new MigraDoc.DocumentObjectModel.ListInfo();

                TheListInfo.ListType = p_BulletType;

                TheListInfo.ContinuePreviousList = (ItemIndex > 0);

                TheParagraph = TheTextFrame.AddParagraph(TheItem);

                TheParagraph.Style = StyleName;

                TheParagraph.Format.ListInfo = TheListInfo;

            }

            TheDocumentRenderer = new MigraDoc.Rendering.DocumentRenderer(TheDocument);
            TheDocumentRenderer.PrepareDocument();
            TheDocumentRenderer.RenderObject(p_Graphics, X, Y, Width, TheTextFrame);

        }

        static void Main(string[] args)
        {

            string[] List;
            string FileName;
            Double BulletWidth;
            Double XIncrement;
            Double YIncrement;
            PdfSharp.Pdf.PdfDocument TheDocument = new PdfSharp.Pdf.PdfDocument();
            PdfSharp.Pdf.PdfPage ThePage = TheDocument.AddPage();
            PdfSharp.Drawing.XGraphics TheGraphics = PdfSharp.Drawing.XGraphics.FromPdfPage(ThePage);
            MigraDoc.DocumentObjectModel.ListType BulletType;
            Double X = 0.5;
            Double Y = 1.0;
            Double Width = 7.5;

            try
            {

                FileName = args[0];

                List = args[1].Split('|');

                BulletWidth = Double.Parse(args[2]);

                XIncrement = Double.Parse(args[3]);

                YIncrement = Double.Parse(args[4]);

                File.Delete(FileName);

                for (BulletType = MigraDoc.DocumentObjectModel.ListType.BulletList1; BulletType <= MigraDoc.DocumentObjectModel.ListType.NumberList3; BulletType++) {

                    RenderBullets(List,TheGraphics,BulletType,BulletWidth,X,Y,Width);

                    X = X + XIncrement;

                    Width = 8.5 - (X + 0.5);

                    Y = Y + YIncrement;

                }

                TheDocument.Save(FileName);

                Console.WriteLine("Document [{0}] Created.",FileName);

            }
            catch (Exception e)
            {
                Console.WriteLine("Exception:[{0}]", e.Message);
            }

            Console.WriteLine("Press Enter to exit...");
            Console.ReadLine();

        }
    }
}
